@@ -761,7 +761,7 @@ sub _format_footnote {
         # multiple paragraphs separated by a blank line in a footnote.
         # However, this is going to fail with footnotes in the
         # headings, so we have to call \endgraf instead
-        $footnote =~ s/\\forcelinebreak /\\endgraf /g;
+        $footnote =~ s/\\forcelinebreak /\\par /g;
         if ($element->type eq 'secondary_footnote') {
             return '\footnoteB{' . $footnote . '}';
         }
